/*
 *  CSS Style Sheet for "My Portal", part of the Galeon distribution
 */

body
{
	font:		11pt sans-serif;
	margin:		0px;
	background:	white;
	color:      	black;
	line-height:	1.7em;
}

div.folder
{
	margin:	1em 0px 0px 2em;
}


/* smaller left margin for the first bookmark folder */
body > div.folder
{
	margin-top:  2em;
	margin-left: 1em;
}

h1.folderheading
{
	border:		1px solid #000000;
	padding:	2px 0.5em;
	background:	#97b1d8;
	font-size:	120%;
	font-weight:	normal;
	display: 	inline;
}

div.foldercontents
{
	margin:		1em 0em 1em 1em;
}

div.separator
{
	height:         0em;
}

.top2
{
 	margin:		0px;
	padding:	2px;
	border-bottom:	1px solid #000000;
	border-top:	1px solid #000000;
	height:		20px;
}

.top2 img.logo
{
	margin-top:	1em;
	width:		318px;
	height:		239px;
	margin-left:	10px;
	border:		0px;
	float:		right;
}

.top_bar
{
  	background: 	#97b1d8;
  	font-family: 	helvetic, helvetica, arial;
  	font-size: 	20px;
  	height: 	30px;
	margin:		0px;
	padding-top:	5px;
	padding-right:	15px;
	padding-left:	15px;
	border-bottom:	1px solid #000000;
}

.bottom_bar
{
  	background: #97b1d8;
 	margin-left: 	224px;
 	margin-right: 	224px;
	margin-top:	40px;
	margin-bottom:	20px;
	padding-top:	1px;
	padding-bottom:	1px;
	text-align:     center;
	border:			2px solid #000000;
	border-top:		1px solid #000000;
	border-right:		1px solid #000000;
	border-left:		1px solid #000000;
}

/* various link styles */
a,
a:link,
a:visited
{
        white-space:            nowrap;
	color:			black;
	text-decoration:	none;
	border-bottom:		1px solid grey;
}

a:hover
{
	color:			blue;
	border-bottom:		1px solid black;
}

.foldercontents > a
{
	margin-right:		12px;
}


/* links in category headings have a different class */
.folderheading a,
.folderheading a:link,
.folderheading a:visited
{
	color:			black;
	border-bottom:		0px;
	margin-left: 		0.5em;
	margin-right: 		0.5em;
}

.folderheading a:hover
{
	color:			#00009c;
	text-decoration:	underline;
}


img
{
	border:		0px;
}

input
{
	margin:	6px 5px 0px 3px;
}

input[type="image"]
{
	border:	0px;
}
